@@ -38,6 +38,6 @@
 # del fns
 # # del document
 
-from utils import show_gpuinfo
+# from utils import show_gpuinfo
 
-show_gpuinfo()
\ No newline at end of file
+# show_gpuinfo()
